
:autogenerated:
..
    This file is autogenerated by `generate_custom_files` in conf.py,
    and ought to be generated via building the documentation through Sphinx, e.g.
    with `sphinx-build ./web ./build` from the root directory.

nltk.test.unit.test_concordance module
======================================

.. currentmodule:: nltk.test.unit.test_concordance

.. automodule:: nltk.test.unit.test_concordance
    :members:
    :undoc-members:
    :show-inheritance:
    :member-order: bysource